import React, { Component } from 'react'
import UserCard from './UserCard.js'
import { 
  FGHAZI_PRESENCE,
  BOT_PRESENCE,
  ITDEVS_PRESENCE,
  BOTS_WITH_ONE_BAD_SIP_PRESENCE
} from '../lib/vars'

class PresenceTestContainer extends Component {
  constructor() {
    super();
    
    // On initial state, set users to an empty array
    this.state = {
      getPresencesApiUrl: ITDEVS_PRESENCE,
      users: [],
      apiFetchingRefreshInterval: 3000, // 1 second = 1000
      secondsElapsed: 0,
    }

    this.getData = this.getData.bind(this);
  }

  // Call this function to fetch data from the Web Presence API
  getData() {
    fetch(this.state.getPresencesApiUrl)
      .then(response => response.json()) // Parse response to json
      .then(json => {
        console.log('getData()')
        console.log(json)
        let nextState = Object.assign(this.state, {users: json, timeElapsed: this.state.secondsElapsed + 1})
        this.setState(nextState)
      })
      .catch(error => console.log(error))
  }

  // This function is called ater component is rendered into the browser.
  // And this function will fetch data from the api then store it as state.
  componentDidMount() {
    this.getData()
    this.interval = setInterval(this.getData, this.state.apiFetchingRefreshInterval)
  }

  // Before component mounts, clear interval
  componentWillMount() {
    clearInterval(this.interval);
  }

  render() {
    const USERS = this.state.users;
    return(
      <div className='container'>
        <h1>Presence App Test </h1>
        <h5>{USERS.length} Agents</h5>
        <h5>{this.state.apiFetchingRefreshInterval / 1000} seconds refresh interval</h5>
        <div className='row'>
        
          {USERS.map((user, index) => (
            <UserCard className='col-3' foo={user} key={user.Email}/>
          ))}
        </div>
        
      </div>
    );
  }
}

export default PresenceTestContainer;